@@ -97,7 +97,7 @@ class Test_fit(unittest.TestCase):
         except ValueError:
             pass
         sys.stdout = sys.__stdout__
-        expected = "The 'comparison' parameter only accepts 'critical' or 'p-value' as values, but we got 'any'"
+        expected = "The 'conclusion' parameter only accepts 'critical' or 'p-value' as values, but we got 'any'"
         result = False
         if expected in capturedOutput.getvalue():
             result = True
@@ -113,7 +113,7 @@ class Test_fit(unittest.TestCase):
         except ValueError:
             pass
         sys.stdout = sys.__stdout__
-        expected = "The 'comparison' parameter only accepts 'critical' or 'p-value' as values, but we got 'tabulated'"
+        expected = "The 'conclusion' parameter only accepts 'critical' or 'p-value' as values, but we got 'tabulated'"
         result = False
         if expected in capturedOutput.getvalue():
             result = True
@@ -130,7 +130,7 @@ class Test_fit(unittest.TestCase):
         except ValueError:
             pass
         sys.stdout = sys.__stdout__
-        expected = "The 'comparison' parameter only accepts 'critical' or 'p-value' as values, but we got 'p_value'"
+        expected = "The 'conclusion' parameter only accepts 'critical' or 'p-value' as values, but we got 'p_value'"
         result = False
         if expected in capturedOutput.getvalue():
             result = True
@@ -379,7 +379,7 @@ class Test_fit(unittest.TestCase):
         except ValueError:
             pass
         sys.stdout = sys.__stdout__
-        expected = "The 'comparison' parameter only accepts 'critical' or 'p-value' as values, but we got 'any'"
+        expected = "The 'conclusion' parameter only accepts 'critical' or 'p-value' as values, but we got 'any'"
         result = False
         if expected in capturedOutput.getvalue():
             result = True
@@ -395,7 +395,7 @@ class Test_fit(unittest.TestCase):
         except ValueError:
             pass
         sys.stdout = sys.__stdout__
-        expected = "The 'comparison' parameter only accepts 'critical' or 'p-value' as values, but we got 'tabulated'"
+        expected = "The 'conclusion' parameter only accepts 'critical' or 'p-value' as values, but we got 'tabulated'"
         result = False
         if expected in capturedOutput.getvalue():
             result = True
@@ -412,7 +412,7 @@ class Test_fit(unittest.TestCase):
         except ValueError:
             pass
         sys.stdout = sys.__stdout__
-        expected = "The 'comparison' parameter only accepts 'critical' or 'p-value' as values, but we got 'p_value'"
+        expected = "The 'conclusion' parameter only accepts 'critical' or 'p-value' as values, but we got 'p_value'"
         result = False
         if expected in capturedOutput.getvalue():
             result = True
